# Changelog

<!--next-version-placeholder-->

## v1.2.0 (2022-05-31)
### Feature
* Registration feature ([#1](https://github.com/draganagrbic998/devops_auth_service/issues/1)) ([`4cf0133`](https://github.com/draganagrbic998/devops_auth_service/commit/4cf0133d3b56b193227f0dbe40e39a432606eaed))

## v1.1.0 (2022-05-31)
### Feature
* Init auth service ([`510ce6c`](https://github.com/draganagrbic998/devops_auth_service/commit/510ce6c893c5dc88f0ffd3e0a0eb74a5cd7a9a7c))
